[Lldb-commits] [PATCH] D114819: [lldb] Split TestCxxChar8_t

Jonas Devlieghere via Phabricator via lldb-commits lldb-commits at lists.llvm.org
Wed Dec 1 16:59:02 PST 2021


This revision was automatically updated to reflect the committed changes.
Closed by commit rG8f329cee4237: [lldb] Split TestCxxChar8_t (authored by JDevlieghere).
Herald added a project: LLDB.

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D114819/new/

https://reviews.llvm.org/D114819

Files:
  lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py


Index: lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
===================================================================
--- lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
+++ lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
@@ -15,13 +15,12 @@
     mydir = TestBase.compute_mydir(__file__)
 
     @skipIf(compiler="clang", compiler_version=['<', '7.0'])
-    def test(self):
-        """Test that C++ supports char8_t correctly."""
+    @expectedFailureDarwin(archs=["arm64", "arm64e"]) # <rdar://problem/37773624>
+    def test_without_process(self):
+        """Test that C++ supports char8_t without a running process."""
         self.build()
-
         lldbutil.run_to_breakpoint_make_target(self)
 
-        # Make sure the variables can be printed without a running process.
         self.expect("target variable a", substrs=["char8_t", "0x61 u8'a'"])
         self.expect("target variable ab",
                 substrs=["const char8_t *", 'u8"你好"'])
@@ -29,11 +28,16 @@
 
         self.expect_expr("a", result_type="char8_t", result_summary="0x61 u8'a'")
         self.expect_expr("ab", result_type="const char8_t *", result_summary='u8"你好"')
+
         # FIXME: This should work too.
         self.expect("expr abc", substrs=['u8"你好"'], matching=False)
 
-        lldbutil.run_break_set_by_source_regexp(self, "// break here", "-f main.cpp")
-        self.runCmd("run")
+
+    @skipIf(compiler="clang", compiler_version=['<', '7.0'])
+    def test_with_process(self):
+        """Test that C++ supports char8_t with a running process."""
+        self.build()
+        lldbutil.run_to_source_breakpoint(self, '// break here', lldb.SBFileSpec("main.cpp"))
 
         # As well as with it
         self.expect_expr("a", result_type="char8_t", result_summary="0x61 u8'a'")


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D114819.391170.patch
Type: text/x-patch
Size: 1797 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/lldb-commits/attachments/20211202/b74446bf/attachment-0001.bin>


More information about the lldb-commits mailing list